summaryrefslogtreecommitdiffstats
path: root/kate/plugins
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /kate/plugins
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kate/plugins')
-rw-r--r--kate/plugins/autobookmarker/autobookmarker.cpp54
-rw-r--r--kate/plugins/autobookmarker/autobookmarker.h4
-rw-r--r--kate/plugins/autobookmarker/ktexteditor_autobookmarkerrc12
-rw-r--r--kate/plugins/isearch/ktexteditor_isearchui.rc4
-rw-r--r--kate/plugins/kdatatool/kate_kdatatool.cpp10
-rw-r--r--kate/plugins/wordcompletion/docwordcompletion.cpp12
-rw-r--r--kate/plugins/wordcompletion/docwordcompletion.h4
-rw-r--r--kate/plugins/wordcompletion/ktexteditor_docwordcompletion.desktop2
8 files changed, 51 insertions, 51 deletions
diff --git a/kate/plugins/autobookmarker/autobookmarker.h b/kate/plugins/autobookmarker/autobookmarker.h
index 4fe8b44dd..bdeb2abcf 100644
--- a/kate/plugins/autobookmarker/autobookmarker.h
+++ b/kate/plugins/autobookmarker/autobookmarker.h
@@ -41,8 +41,8 @@ class AutoBookmarkEnt
int flags=1 );
~AutoBookmarkEnt(){};
TQString pattern;
- TQStringList filetqmask;
- TQStringList mimetqmask;
+ TQStringList filemask;
+ TQStringList mimemask;
int flags;
};
diff --git a/kate/plugins/autobookmarker/ktexteditor_autobookmarkerrc b/kate/plugins/autobookmarker/ktexteditor_autobookmarkerrc
index c79ade799..3ed8fe8c5 100644
--- a/kate/plugins/autobookmarker/ktexteditor_autobookmarkerrc
+++ b/kate/plugins/autobookmarker/ktexteditor_autobookmarkerrc
@@ -1,18 +1,18 @@
[autobookmark0]
-filetqmask=*.pl;*.pm
+filemask=*.pl;*.pm
flags=1
-mimetqmask=text/x-perl
+mimemask=text/x-perl
pattern=sub \\w+
[autobookmark1]
-filetqmask=*.hh;*.h
+filemask=*.hh;*.h
flags=1
-mimetqmask=text/x-c++hdr
+mimemask=text/x-c++hdr
pattern=^class\\s+[^;]+$
[autobookmark2]
-filetqmask=*.js;*.html;*.HTML;*.htm;*.HTM;*.xhtml;*.asp
+filemask=*.js;*.html;*.HTML;*.htm;*.HTM;*.xhtml;*.asp
flags=1
-mimetqmask=application/x-javascript;text/html
+mimemask=application/x-javascript;text/html
pattern=\\s*function\\s+\\w+
diff --git a/kate/plugins/isearch/ktexteditor_isearchui.rc b/kate/plugins/isearch/ktexteditor_isearchui.rc
index a65d270ef..d8fc6b5dd 100644
--- a/kate/plugins/isearch/ktexteditor_isearchui.rc
+++ b/kate/plugins/isearch/ktexteditor_isearchui.rc
@@ -2,8 +2,8 @@
<kpartplugin name="ktexteditor_isearch" library="ktexteditor_isearch" version="4">
<MenuBar>
<Menu name="edit"><text>&amp;Edit</text>
- <Action name="edit_isearch" group="edit_tqfind_merge"/>
- <Action name="edit_isearch_reverse" group="edit_tqfind_merge"/>
+ <Action name="edit_isearch" group="edit_find_merge"/>
+ <Action name="edit_isearch_reverse" group="edit_find_merge"/>
</Menu>
</MenuBar>
<ToolBar name="isearchToolBar" hidden="true"><text>Search Toolbar</text>
diff --git a/kate/plugins/wordcompletion/docwordcompletion.h b/kate/plugins/wordcompletion/docwordcompletion.h
index cb7349da5..ed632631a 100644
--- a/kate/plugins/wordcompletion/docwordcompletion.h
+++ b/kate/plugins/wordcompletion/docwordcompletion.h
@@ -106,7 +106,7 @@ class DocWordCompletionPluginView
TQString word();
TQValueList<KTextEditor::CompletionEntry> allMatches( const TQString &word );
- TQString tqfindLongestUnique(const TQValueList < KTextEditor::CompletionEntry > &matches);
+ TQString findLongestUnique(const TQValueList < KTextEditor::CompletionEntry > &matches);
KTextEditor::View *m_view;
struct DocWordCompletionPluginViewPrivate *d;
};
@@ -130,4 +130,4 @@ class DocWordCompletionConfigPage : public KTextEditor::ConfigPage
};
#endif // _DocWordCompletionPlugin_h_
-// kate: space-indent on; indent-width 2; tqreplace-tabs on; mixed-indent off;
+// kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
diff --git a/kate/plugins/wordcompletion/ktexteditor_docwordcompletion.desktop b/kate/plugins/wordcompletion/ktexteditor_docwordcompletion.desktop
index 5941a1957..dd2a5e8dc 100644
--- a/kate/plugins/wordcompletion/ktexteditor_docwordcompletion.desktop
+++ b/kate/plugins/wordcompletion/ktexteditor_docwordcompletion.desktop
@@ -117,7 +117,7 @@ Comment[pt_BR]=Complementação direcional, ou baseada em popup, de palavras do
Comment[ro]=Propune completarea cuvintelor din document dintr-o listă popup sau direcţională
Comment[ru]=Автодополнение слов в документе
Comment[rw]=Irangiza mfatacyerekezo cyangwa rishingiye-kwirambura biva ku magambo yo mu nyandiko
-Comment[sk]=Dopĺňanie slov v dokumente priame alebo potqmocou dialógu
+Comment[sk]=Dopĺňanie slov v dokumente priame alebo pomocou dialógu
Comment[sl]=Neposredno ali pojavno dopolnjevanje iz besed v dokumentu
Comment[sr]=Директна или искачућа допуна од речи у документу
Comment[sr@Latn]=Direktna ili iskačuća dopuna od reči u dokumentu
diff --git a/kate/plugins/autobookmarker/autobookmarker.cpp b/kate/plugins/autobookmarker/autobookmarker.cpp
index 833aa629c..c03fcefe0 100644
--- a/kate/plugins/autobookmarker/autobookmarker.cpp
+++ b/kate/plugins/autobookmarker/autobookmarker.cpp
@@ -124,7 +124,7 @@ void AutoBookmarker::slotCompleted()
fileName = document()->url().fileName();
ABEntityList *l = ABGlobal::self()->entities();
- // for each item, if either tqmask matches
+ // for each item, if either mask matches
// * apply if onLoad is true
ABEntityListIterator it( *l );
int n( 0 );
@@ -132,11 +132,11 @@ void AutoBookmarker::slotCompleted()
AutoBookmarkEnt *e;
while ( ( e = it.current() ) != 0 )
{
- found = ( !e->mimetqmask.count() && !e->filetqmask.count() ); // no preferences
+ found = ( !e->mimemask.count() && !e->filemask.count() ); // no preferences
if ( ! found )
- found = ( ! mt.isEmpty() && e->mimetqmask.tqcontains( mt ) );
+ found = ( ! mt.isEmpty() && e->mimemask.contains( mt ) );
if ( ! found )
- for( TQStringList::Iterator it1 = e->filetqmask.begin(); it1 != e->filetqmask.end(); ++it1 )
+ for( TQStringList::Iterator it1 = e->filemask.begin(); it1 != e->filemask.end(); ++it1 )
{
TQRegExp re(*it1, true, true);
if ( ( found = ( ( re.search( fileName ) > -1 ) && ( re.matchedLength() == (int)fileName.length() ) ) ) )
@@ -206,13 +206,13 @@ void ABGlobal::readConfig()
while ( config->hasGroup( TQString("autobookmark%1").arg( n ) ) )
{
config->setGroup( TQString("autobookmark%1").arg( n ) );
- TQStringList filetqmask = config->readListEntry( "filetqmask", ';' );
- TQStringList mimetqmask = config->readListEntry( "mimetqmask", ';' );
+ TQStringList filemask = config->readListEntry( "filemask", ';' );
+ TQStringList mimemask = config->readListEntry( "mimemask", ';' );
int flags = config->readNumEntry( "flags", 1 );
AutoBookmarkEnt *e = new AutoBookmarkEnt(
config->readEntry( "pattern", "" ),
- filetqmask,
- mimetqmask,
+ filemask,
+ mimemask,
flags
);
@@ -239,8 +239,8 @@ void ABGlobal::writeConfig()
AutoBookmarkEnt *e = m_ents->at( i );
config->setGroup( TQString("autobookmark%1").arg( i ) );
config->writeEntry( "pattern", e->pattern );
- config->writeEntry( "filetqmask", e->filetqmask, ';' );
- config->writeEntry( "mimetqmask", e->mimetqmask, ';' );
+ config->writeEntry( "filemask", e->filemask, ';' );
+ config->writeEntry( "mimemask", e->mimemask, ';' );
config->writeEntry( "flags", e->flags );
}
@@ -264,8 +264,8 @@ class AutoBookmarkEntItem : public QListViewItem
void redo()
{
setText( 0, ent->pattern );
- setText( 1, ent->mimetqmask.join("; ") );
- setText( 2, ent->filetqmask.join("; ") );
+ setText( 1, ent->mimemask.join("; ") );
+ setText( 2, ent->filemask.join("; ") );
}
AutoBookmarkEnt *ent;
};
@@ -274,7 +274,7 @@ class AutoBookmarkEntItem : public QListViewItem
//BEGIN AutoBookmarkerEntEditor
// Dialog for editing a single autobookmark entity
// * edit the pattern
// * set the file/mime type tqmasks
AutoBookmarkerEntEditor::AutoBookmarkerEntEditor( TQWidget *parent, AutoBookmarkEnt *e )
: KDialogBase( parent, "autobookmark_ent_editor",
true, i18n("Edit Entry"),
@@ -310,19 +310,19 @@ AutoBookmarkerEntEditor::AutoBookmarkerEntEditor( TQWidget *parent, AutoBookmark
"do not know what that is, please read the appendix on regular expressions "
"in the kate manual.</p>") );
- l = new TQLabel( i18n("&File tqmask:"), w );
- leFileMask = new TQLineEdit( e->filetqmask.join( "; " ), w );
+ l = new TQLabel( i18n("&File mask:"), w );
+ leFileMask = new TQLineEdit( e->filemask.join( "; " ), w );
l->setBuddy( leFileMask );
lo->addWidget( l, 3, 0 );
lo->addMultiCellWidget( leFileMask, 3, 3, 1, 2 );
TQWhatsThis::add( leFileMask, i18n(
- "<p>A list of filename tqmasks, separated by semicolons. This can be used "
+ "<p>A list of filename masks, separated by semicolons. This can be used "
"to limit the usage of this entity to files with matching names.</p>"
"<p>Use the wizard button to the right of the mimetype entry below to "
"easily fill out both lists.</p>" ) );
l = new TQLabel( i18n("MIME &types:"), w );
- leMimeTypes = new TQLineEdit( e->mimetqmask.join( "; " ), w );
+ leMimeTypes = new TQLineEdit( e->mimemask.join( "; " ), w );
l->setBuddy( leMimeTypes );
lo->addWidget( l, 4, 0 );
lo->addWidget( leMimeTypes, 4, 1 );
@@ -330,7 +330,7 @@ AutoBookmarkerEntEditor::AutoBookmarkerEntEditor( TQWidget *parent, AutoBookmark
"<p>A list of mime types, separated by semicolon. This can be used to "
"limit the usage of this entity to files with matching mime types.</p>"
"<p>Use the wizard button on the right to get a list of existing file "
- "types to choose from, using it will fill in the file tqmasks as well.</p>" ) );
+ "types to choose from, using it will fill in the file masks as well.</p>" ) );
TQToolButton *btnMTW = new TQToolButton(w);
lo->addWidget( btnMTW, 4, 2 );
@@ -338,8 +338,8 @@ AutoBookmarkerEntEditor::AutoBookmarkerEntEditor( TQWidget *parent, AutoBookmark
connect(btnMTW, TQT_SIGNAL(clicked()), this, TQT_SLOT(showMTDlg()));
TQWhatsThis::add( btnMTW, i18n(
"<p>Click this button to display a checkable list of mimetypes available "
- "on your system. When used, the file tqmasks entry above will be filled in "
- "with the corresponding tqmasks.</p>") );
+ "on your system. When used, the file masks entry above will be filled in "
+ "with the corresponding masks.</p>") );
slotPatternChanged( lePattern->text() );
}
@@ -353,8 +353,8 @@ void AutoBookmarkerEntEditor::apply()
if ( lePattern->text().isEmpty() ) return;
e->pattern = lePattern->text();
- e->filetqmask = TQStringList::split( TQRegExp("\\s*;\\s*"), leFileMask->text() );
- e->mimetqmask = TQStringList::split( TQRegExp("\\s*;\\s*"), leMimeTypes->text() );
+ e->filemask = TQStringList::split( TQRegExp("\\s*;\\s*"), leFileMask->text() );
+ e->mimemask = TQStringList::split( TQRegExp("\\s*;\\s*"), leMimeTypes->text() );
e->flags = 0;
if ( cbCS->isOn() ) e->flags |= AutoBookmarkEnt::CaseSensitive;
if ( cbMM->isOn() ) e->flags |= AutoBookmarkEnt::MinimalMatching;
@@ -394,7 +394,7 @@ AutoBookmarkerConfigPage::AutoBookmarkerConfigPage( TQWidget *parent, const char
"<p>This list shows your configured autobookmark entities. When a document "
"is opened, each entity is used in the following way: "
"<ol>"
- "<li>The entity is dismissed, if a mime and/or filename tqmask is defined, "
+ "<li>The entity is dismissed, if a mime and/or filename mask is defined, "
"and neither matches the document.</li>"
"<li>Otherwise each line of the document is tried against the pattern, "
"and a bookmark is set on matching lines.</li></ul>"
@@ -430,7 +430,7 @@ AutoBookmarkerConfigPage::AutoBookmarkerConfigPage( TQWidget *parent, const char
reset();
}
-// tqreplace the global list with the new one
+// replace the global list with the new one
void AutoBookmarkerConfigPage::apply()
{
ABGlobal::self()->entities()->clear();
@@ -490,7 +490,7 @@ void AutoBookmarkerConfigPage::slotNew()
void AutoBookmarkerConfigPage::slotDel()
{
AutoBookmarkEntItem *i = (AutoBookmarkEntItem*)lvPatterns->currentItem();
- int idx = m_ents->tqfindRef( i->ent );
+ int idx = m_ents->findRef( i->ent );
m_ents->remove( idx );
delete i;
}
@@ -511,8 +511,8 @@ void AutoBookmarkerConfigPage::slotEdit()
//BEGIN AutoBookmarkEnt
AutoBookmarkEnt::AutoBookmarkEnt( const TQString &p, const TQStringList &f, const TQStringList &m, int fl )
: pattern( p ),
- filetqmask( f ),
- mimetqmask( m ),
+ filemask( f ),
+ mimemask( m ),
flags( fl )
{;
}
@@ -274,7 +274,7 @@ class AutoBookmarkEntItem : public QListViewItem
// Dialog for editing a single autobookmark entity
// * edit the pattern
-// * set the file/mime type tqmasks
+// * set the file/mime type masks
AutoBookmarkerEntEditor::AutoBookmarkerEntEditor( TQWidget *parent, AutoBookmarkEnt *e )
: KDialogBase( parent, "autobookmark_ent_editor",
diff --git a/kate/plugins/kdatatool/kate_kdatatool.cpp b/kate/plugins/kdatatool/kate_kdatatool.cpp
index 5a0308b50..11cd645b7 100644
--- a/kate/plugins/kdatatool/kate_kdatatool.cpp
+++ b/kate/plugins/kdatatool/kate_kdatatool.cpp
@@ -108,7 +108,7 @@ void KDataToolPluginView::aboutToShow()
if ( selectionInterface(m_view->document())->hasSelection() )
{
word = selectionInterface(m_view->document())->selection();
- if ( word.tqfind(' ') == -1 && word.tqfind('\t') == -1 && word.tqfind('\n') == -1 )
+ if ( word.find(' ') == -1 && word.find('\t') == -1 && word.find('\n') == -1 )
m_singleWord = true;
else
m_singleWord = false;
@@ -123,7 +123,7 @@ void KDataToolPluginView::aboutToShow()
ci->cursorPositionReal(&line, &col);
TQString tmp_line = ei->textLine(line);
m_wordUnderCursor = "";
// tqfind begin of word:
m_singleWord_start = 0;
for(int i = col; i >= 0; i--) {
TQChar ch = tmp_line.at(i);
@@ -134,7 +134,7 @@ void KDataToolPluginView::aboutToShow()
}
m_wordUnderCursor = ch + m_wordUnderCursor;
}
// tqfind end of word:
m_singleWord_end = tmp_line.length();
for(uint i = col+1; i < tmp_line.length(); i++) {
TQChar ch = tmp_line.at(i);
@@ -206,7 +206,7 @@ void KDataToolPluginView::slotToolActivated( const KDataToolInfo &info, const TQ
TQString datatype = "TQString";
// If unsupported (and if we have a single word indeed), try application/x-singleword
- if ( !info.mimeTypes().tqcontains( mimetype ) && m_singleWord )
+ if ( !info.mimeTypes().contains( mimetype ) && m_singleWord )
mimetype = "application/x-singleword";
kdDebug() << "Running tool with datatype=" << datatype << " mimetype=" << mimetype << endl;
@@ -227,7 +227,7 @@ void KDataToolPluginView::slotToolActivated( const KDataToolInfo &info, const TQ
si->setSelection(m_singleWord_line, m_singleWord_start, m_singleWord_line, m_singleWord_end);
}
- // tqreplace selection with 'text'
+ // replace selection with 'text'
selectionInterface(m_view->document())->removeSelectedText();
viewCursorInterface(m_view)->cursorPositionReal(&line, &col);
editInterface(m_view->document())->insertText(line, col, text);
@@ -123,7 +123,7 @@ void KDataToolPluginView::aboutToShow()
TQString tmp_line = ei->textLine(line);
m_wordUnderCursor = "";
- // tqfind begin of word:
+ // find begin of word:
m_singleWord_start = 0;
for(int i = col; i >= 0; i--) {
@@ -134,7 +134,7 @@ void KDataToolPluginView::aboutToShow()
m_wordUnderCursor = ch + m_wordUnderCursor;
}
- // tqfind end of word:
+ // find end of word:
m_singleWord_end = tmp_line.length();
for(uint i = col+1; i < tmp_line.length(); i++) {
diff --git a/kate/plugins/wordcompletion/docwordcompletion.cpp b/kate/plugins/wordcompletion/docwordcompletion.cpp
index 7bd0e83e0..37da55224 100644
--- a/kate/plugins/wordcompletion/docwordcompletion.cpp
+++ b/kate/plugins/wordcompletion/docwordcompletion.cpp
@@ -232,7 +232,7 @@ void DocWordCompletionPluginView::shellComplete()
{
// setup
KTextEditor::EditInterface * ei = KTextEditor::editInterface(m_view->document());
// tqfind the word we are typing
uint cline, ccol;
viewCursorInterface(m_view)->cursorPositionReal(&cline, &ccol);
TQString wrd = word();
@@ -242,7 +242,7 @@ void DocWordCompletionPluginView::shellComplete()
TQValueList < KTextEditor::CompletionEntry > matches = allMatches(wrd);
if (matches.size() == 0)
return;
- TQString partial = tqfindLongestUnique(matches);
+ TQString partial = findLongestUnique(matches);
if (partial.length() == wrd.length())
{
KTextEditor::CodeCompletionInterface * cci = codeCompletionInterface(m_view);
@@ -261,7 +261,7 @@ void DocWordCompletionPluginView::complete( bool fw )
{
// setup
KTextEditor::EditInterface *ei = KTextEditor::editInterface( m_view->document() );
// tqfind the word we are typing
uint cline, ccol;
viewCursorInterface( m_view )->cursorPositionReal( &cline, &ccol );
TQString wrd = word();
@@ -333,7 +333,7 @@ void DocWordCompletionPluginView::complete( bool fw )
TQString m = d->re.cap( 1 );
if ( m != d->lastIns )
{
- // we got good a match! tqreplace text and return.
+ // we got good a match! replace text and return.
if ( d->lilen )
ei->removeText( d->cline, d->ccol, d->cline, d->ccol + d->lilen );
ei->insertText( d->cline, d->ccol, m );
@@ -393,7 +393,7 @@ void DocWordCompletionPluginView::complete( bool fw )
}
// Contributed by <brain@hdsnet.hu>
-TQString DocWordCompletionPluginView::tqfindLongestUnique(const TQValueList < KTextEditor::CompletionEntry > &matches)
+TQString DocWordCompletionPluginView::findLongestUnique(const TQValueList < KTextEditor::CompletionEntry > &matches)
{
TQString partial = matches.front().text;
TQValueList < KTextEditor::CompletionEntry >::const_iterator i = matches.begin();
@@ -551,4 +551,4 @@ void DocWordCompletionConfigPage::defaults()
//END DocWordCompletionConfigPage
#include "docwordcompletion.moc"
-// kate: space-indent on; indent-width 2; tqreplace-tabs on; mixed-indent off;
+// kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
@@ -232,7 +232,7 @@ void DocWordCompletionPluginView::shellComplete()
// setup
KTextEditor::EditInterface * ei = KTextEditor::editInterface(m_view->document());
- // tqfind the word we are typing
+ // find the word we are typing
uint cline, ccol;
viewCursorInterface(m_view)->cursorPositionReal(&cline, &ccol);
@@ -261,7 +261,7 @@ void DocWordCompletionPluginView::complete( bool fw )
// setup
KTextEditor::EditInterface *ei = KTextEditor::editInterface( m_view->document() );
- // tqfind the word we are typing
+ // find the word we are typing
uint cline, ccol;
viewCursorInterface( m_view )->cursorPositionReal( &cline, &ccol );